pub struct NetAddress(pub u32);
Structure for wrapping a Blaze networking address

Tuple Fields

0: u32

Implementations

Addresses where the value is zero are considered to be invalid addresses that could not be parsed. Parsing these addresses would result in the address 0.0.0.0

Converts the provided IPv4 string into a NetAddress

Attempts to convert the provided IP address string into a NetAddress value. If the value is not a valid IPv4 address then None will be returned.

Converts the value stored in this NetAddress to an IPv4 string