Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Function for implementing decoding of Self from
the provided Reader. Will return None if self
cannot be decoded
Read more
Returns the “default value” for a type.
Read more
Function for implementing encoding of Self to the
provided vec of bytes
Read more
Shortcut function for encoding self directly to
a Vec of bytes
Read more
Serialize this value into the given Serde serializer.
Read more
The type of tdf value this is
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.