pub struct AttributesChange<'a> {
pub id: GameID,
pub attributes: &'a AttrMap,
}
Packet for game attribute changes
The id of the game the attributes have changed for
Borrowed game attributes map
Function for implementing encoding of Self to the
provided vec of bytes
Read more
Shortcut function for encoding self directly to
a Vec of bytes
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.