pub struct RuleSet { /* private fields */ }
Structure for a set of rules used to determine
whether a matchmaking query matches a game.
Creates a new rule set from the provided vec of match rules.
Attempts to see if the provided game matches the rules
in this rule set. Its okay for the values of rules to be
missing and rules with unknown values are treated as a
failure.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.