Struct pocket_relay_core::blaze::codec::NetAddress
source · pub struct NetAddress(pub u32);Expand description
Structure for wrapping a Blaze networking address
Tuple Fields
0: u32Implementations
sourceimpl NetAddress
impl NetAddress
sourcepub fn is_invalid(&self) -> bool
pub fn is_invalid(&self) -> bool
Addresses where the value is zero are considered to be invalid addresses that could not be parsed. Parsing these addresses would result in the address 0.0.0.0
sourcepub fn from_ipv4(value: &str) -> NetAddress
pub fn from_ipv4(value: &str) -> NetAddress
Converts the provided IPv4 string into a NetAddress
sourcepub fn try_from_ipv4(value: &str) -> Option<NetAddress>
pub fn try_from_ipv4(value: &str) -> Option<NetAddress>
Attempts to convert the provided IP address string into a NetAddress value. If the value is not a valid IPv4 address then None will be returned.